==> claromentis-framework-8.13.65-b8aa1bfb.zip: web/intranet/core/classes/Http/TwigResponse.php <==
<?php
namespace Claromentis\Core\Http;

$GLOBALS["__65da1b1ec2d665" . "3e8a0ab7848e5362" . "15"] = (@$GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"] ?: array()) + array("_f73dab606630b38864" . "5c4f7d3fbb13bb" => base64_decode("YXJy" . "YXlf" . "bWVy" . "Z2U="));




class TwigResponse
{
    
    
    
    
    
    
    protected $template;
    
    
    
    
    
    
    protected $arguments;
    
    
    
    
    protected $http_status;
    
    
    
    
    protected $http_headers;
    
    
    
    
    
    
    
    public function __construct(string $template, array $arguments = [])
    {
        $this->setTemplate($template);
        $this->setArguments($arguments);
        $this->setHttpStatus(200);
        $this->setHttpHeaders([]);
    }
    
    
    
    
    
    
    public function getTemplate() : string
    {
        return $this->template;
    }
    
    
    
    
    
    
    public function setTemplate(string $template) : void
    {
        $this->template = $template;
    }
    
    
    
    
    
    
    public function getArguments() : array
    {
        return $this->arguments;
    }
    
    
    
    
    
    
    public function setArguments(array $arguments) : void
    {
        $this->arguments = $arguments;
    }
    
    
    
    
    
    
    public function addArguments(array $arguments) : void
    {
        $this->arguments = $GLOBALS["__65da1b1ec2" . "d6653e8a0ab7" . "848e536215"]["_f73dab606630b3886" . "45c4f7d3fbb13bb"]($this->arguments, $arguments);
    }
    
    
    
    
    
    
    public function getHttpStatus() : int
    {
        return $this->http_status;
    }
    
    
    
    
    
    
    
    public function setHttpStatus(int $_5cbbc47250bb0d1ba94516fec2c7033c) : void
    {
        $this->http_status = $_5cbbc47250bb0d1ba94516fec2c7033c;
    }
    
    
    
    
    
    
    public function getHttpHeaders() : array
    {
        return $this->http_headers;
    }
    
    
    
    
    
    
    
    
    
    
    
    
    public function setHttpHeaders(array $_bb832a060044346957089d9d9adaa8dd) : void
    {
        $this->http_headers = $_bb832a060044346957089d9d9adaa8dd;
    }
    
    
    
    
    
    
    public function addHttpHeaders(array $_bb832a060044346957089d9d9adaa8dd) : void
    {
        $this->http_headers = $GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"]["_f73dab606630b3886" . "45c4f7d3fbb13bb"]($this->http_headers, $_bb832a060044346957089d9d9adaa8dd);
    }
}

==> claromentis-framework-9.6.5-177028fb.zip: web/intranet/core/classes/Http/TwigResponse.php <==
<?php
namespace Claromentis\Core\Http;

$GLOBALS["__65da1b1ec2d6653e8a0ab7848e53" . "6215"] = (@$GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"] ?: array()) + array("_f73dab606630b388645c4f7d3fb" . "b13bb" => base64_decode("YXJyYXlfbW" . "VyZ2U="));




class TwigResponse
{
    
    
    
    
    
    
    protected $template;
    
    
    
    
    
    
    protected $arguments;
    
    
    
    
    protected $http_status;
    
    
    
    
    protected $http_headers;
    
    
    
    
    
    
    
    public function __construct(string $template, array $arguments = [])
    {
        $this->setTemplate($template);
        $this->setArguments($arguments);
        $this->setHttpStatus(200);
        $this->setHttpHeaders([]);
    }
    
    
    
    
    
    
    public function getTemplate() : string
    {
        return $this->template;
    }
    
    
    
    
    
    
    public function setTemplate(string $template) : void
    {
        $this->template = $template;
    }
    
    
    
    
    
    
    public function getArguments() : array
    {
        return $this->arguments;
    }
    
    
    
    
    
    
    public function setArguments(array $arguments) : void
    {
        $this->arguments = $arguments;
    }
    
    
    
    
    
    
    public function addArguments(array $arguments) : void
    {
        $this->arguments = $GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"]["_f73dab606630b388645c4f7d3fbb" . "13bb"]($this->arguments, $arguments);
    }
    
    
    
    
    
    
    public function getHttpStatus() : int
    {
        return $this->http_status;
    }
    
    
    
    
    
    
    
    public function setHttpStatus(int $_5cbbc47250bb0d1ba94516fec2c7033c) : void
    {
        $this->http_status = $_5cbbc47250bb0d1ba94516fec2c7033c;
    }
    
    
    
    
    
    
    public function getHttpHeaders() : array
    {
        return $this->http_headers;
    }
    
    
    
    
    
    
    
    
    
    
    
    
    public function setHttpHeaders(array $_bb832a060044346957089d9d9adaa8dd) : void
    {
        $this->http_headers = $_bb832a060044346957089d9d9adaa8dd;
    }
    
    
    
    
    
    
    public function addHttpHeaders(array $_bb832a060044346957089d9d9adaa8dd) : void
    {
        $this->http_headers = $GLOBALS["__65da1b1ec2d6653e8a0ab78" . "48e536215"]["_f73dab60" . "6630b3886" . "45c4f7d3f" . "bb13bb"]($this->http_headers, $_bb832a060044346957089d9d9adaa8dd);
    }
}
